# optimize

```{eval-rst}

.. autosummary::
    pyslsqp.optimize
    pyslsqp.get_default_options

```

```{eval-rst}

.. autofunction:: pyslsqp.optimize

.. autofunction:: pyslsqp.get_default_options

```